local _, BigBrother = ...
local L = LibStub("AceLocale-3.0"):GetLocale("BigBrother")
local SpellData = BigBrother.SpellData

local function whisper(name, text)
	if not BigBrother.db.profile.blame then return end
	ChatThrottleLib:SendChatMessage("BULK", "", ("BigBrother> %s"):format(text), "WHISPER", nil, name)
end

function BigBrother:ConsumableCheck(channel)
	local groups = self:GetCheckedGroups()
	local inRaid = IsInRaid()

	local missingFlaskList = {}
	local missingElixirList = {}
	local missingFoodList = {}

	for unit, index in self:IterateGroup() do
		local name, realm = UnitName(unit)
		if not name then break end
		local shortName = name
		if realm then name = name.."-"..realm end

		local subgroup = inRaid and select(3, GetRaidRosterInfo(index)) or 1
		local online = UnitIsConnected(unit)
		local dead = UnitIsDeadOrGhost(unit)

		if online and not dead and groups[subgroup] then

			--check flasks/elixirs
			if self.db.profile.checkFlasks then
				local numElixirs = 0
				for _, spellName in next, SpellData.elixirsBattle do
					if UnitBuff(unit, spellName) then
						numElixirs = numElixirs + 1
						break
					end
				end
				for _, spellName in next, SpellData.elixirsGuardian do
					if UnitBuff(unit, spellName) then
						numElixirs = numElixirs + 1
						break
					end
				end

				if numElixirs == 1 then
					whisper(name, L["One Elixir"])
					missingElixirList[#missingElixirList + 1] = shortName
				elseif numElixirs == 0 then
					local found = nil
					for _, spellName in next, SpellData.flasks do
						if UnitBuff(unit, spellName) then
							found = true
							break
						end
					end
					if not found then
						whisper(name, L["No Flask"])
						missingFlaskList[#missingFlaskList + 1] = shortName
					end
				end
			end

			--check food
			if self.db.profile.checkFood then
				local found = nil
				for _, spellName in next, SpellData.foods do
					local id = select(11, UnitBuff(unit, spellName))
					if id and (not self.db.profile.maxOnly or SpellData.foodsMax[id]) then
						found = true
						break
					end
				end
				if not found then
					whisper(name, L["Not Well Fed"])
					missingFoodList[#missingFoodList + 1] = shortName
				end
			end

		end --if
	end --for

	if #missingElixirList > 0 then
		self:SendChatMessageList(L["One Elixir"], missingElixirList, channel)
	end
	if #missingFlaskList > 0 then
		self:SendChatMessageList(L["No Flask"], missingFlaskList, channel)
	end
	if #missingFoodList > 0 then
		self:SendChatMessageList(L["Not Well Fed"], missingFoodList, channel)
	end
end
